-------------------------------------------------------------------------------
--                L  O  C  A  L     V  A  R  I  A  B  L  E  S
-------------------------------------------------------------------------------

local addonName, L = ...;

-------------------------------------------------------------------------------
--                L  O  C  A  L     F  U  N  C  T  I  O  N  S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
--                G  L  O  B  A  L    F  U  N  C  T  I  O  N  S
-------------------------------------------------------------------------------

--
-- Function to enable/disable Merchant Search
--
function NigglesMerchantSearchEnable()
  -- Check if Merchant Search is enabled
  if (NigglesDBC.settings.UiMerchantSearch) then
    -- Show the search text edit box
    _G["NigglesMerchantSearchBox"]:Show();

    -- Update the Merchant's frame, if shown
    if (_G["MerchantFrame"]:IsShown()) then
      MerchantFrame_Update();
    end
  else
    -- Hide the search text edit box
    _G["NigglesMerchantSearchBox"]:Hide();
  end

  return;
end

--
-- Function used to update the Merchant frame, based on the search text
--
function NigglesMerchantSearchUpdate()
  -- Local Variables
  local itemText;
  local itemButton;
  local merchantButton;
  local searchText;

  -- Check if searching is enabled
  if (NigglesDBC.settings.UiMerchantSearch) then
    -- Get the search text
    searchText = NigglesMerchantSearchBox:GetText();
    if (searchText == SEARCH) then
      searchText = "";
    end

    -- Check if there is any search text to match against
    if ((MerchantFrame.selectedTab == 1) and
        (searchText ~= "") and
        (searchText ~= nil)) then
      -- Convert the search text to lowercase
      searchText = string.lower(searchText);

      -- Show the textures for those buttons that match the search text
      for buttonIdx = 1, MERCHANT_ITEMS_PER_PAGE do
        merchantButton = _G["MerchantItem"..buttonIdx];
        itemButton     = _G["MerchantItem"..buttonIdx.."ItemButton"];
        itemText       = _G["MerchantItem"..buttonIdx.."Name"]:GetText();
        if ((itemButton:IsShown()) and
            (itemText ~= nil) and
            (string.find(string.lower(itemText), searchText, 1, true) ==
              nil)) then
          SetItemButtonNameFrameVertexColor(merchantButton, 0.2, 0.2, 0.2);
          SetItemButtonSlotVertexColor(merchantButton, 0.2, 0.2, 0.2);
          SetItemButtonTextureVertexColor(itemButton, 0.2, 0.2, 0.2);
          SetItemButtonNormalTextureVertexColor(itemButton, 0.2, 0.2, 0.2);
        end
      end
    end

    -- Show/Hide the Clear button
    if (searchText ~= "") then
      NigglesMerchantSearchBox.clearButton:Show();
    else
      NigglesMerchantSearchBox.clearButton:Hide();
    end
  end

  return;
end
